==> zio-aws-globalaccelerator_2.13-5.17.102.8-sources.jar: zio/aws/globalaccelerator/model/DescribeCustomRoutingAcceleratorAttributesResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCustomRoutingAcceleratorAttributesResponse(
    acceleratorAttributes: Option[
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse = {
    import DescribeCustomRoutingAcceleratorAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
      .builder()
      .optionallyWith(
        acceleratorAttributes.map(value => value.buildAwsValue())
      )(_.acceleratorAttributes)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse.ReadOnly =
    zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
      .wrap(buildAwsValue())
}
object DescribeCustomRoutingAcceleratorAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse =
      zio.aws.globalaccelerator.model
        .DescribeCustomRoutingAcceleratorAttributesResponse(
          acceleratorAttributes.map(value => value.asEditable)
        )
    def acceleratorAttributes: Option[
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes.ReadOnly
    ]
    def getAcceleratorAttributes: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes.ReadOnly
    ] =
      AwsError.unwrapOptionField("acceleratorAttributes", acceleratorAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
  ) extends zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse.ReadOnly {
    override val acceleratorAttributes: Option[
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes.ReadOnly
    ] = scala
      .Option(impl.acceleratorAttributes())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
  ): zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-6.20.83.1-sources.jar: zio/aws/globalaccelerator/model/DescribeCustomRoutingAcceleratorAttributesResponse.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeCustomRoutingAcceleratorAttributesResponse(
    acceleratorAttributes: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse = {
    import DescribeCustomRoutingAcceleratorAttributesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
      .builder()
      .optionallyWith(
        acceleratorAttributes.map(value => value.buildAwsValue())
      )(_.acceleratorAttributes)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse.ReadOnly =
    zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
      .wrap(buildAwsValue())
}
object DescribeCustomRoutingAcceleratorAttributesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse =
      zio.aws.globalaccelerator.model
        .DescribeCustomRoutingAcceleratorAttributesResponse(
          acceleratorAttributes.map(value => value.asEditable)
        )
    def acceleratorAttributes: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes.ReadOnly
    ]
    def getAcceleratorAttributes: ZIO[
      Any,
      AwsError,
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes.ReadOnly
    ] =
      AwsError.unwrapOptionField("acceleratorAttributes", acceleratorAttributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
  ) extends zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse.ReadOnly {
    override val acceleratorAttributes: Optional[
      zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.acceleratorAttributes())
      .map(value =>
        zio.aws.globalaccelerator.model.CustomRoutingAcceleratorAttributes
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse
  ): zio.aws.globalaccelerator.model.DescribeCustomRoutingAcceleratorAttributesResponse.ReadOnly =
    new Wrapper(impl)
}
